@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2020 Joël Krähemann
+ * Copyright (C) 2005-2022 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -27,6 +27,17 @@
 
 G_BEGIN_DECLS
 
+#define AGS_TYPE_DIATONIC_SCALE         (ags_diatonic_scale_get_type())
+
+typedef struct _AgsDiatonicScale AgsDiatonicScale;
+
+struct _AgsDiatonicScale
+{
+  //empty
+};
+
+GType ags_diatonic_scale_get_type(void);
+
 guint ags_diatonic_scale_note_to_midi_key(gchar *note,
 					  glong *key);
 guint ags_diatonic_scale_midi_key_to_note(glong key,
